@@ -1,5 +1,10 @@
 import os
 import sys
+import inspect
+from typing import Type
+
+global IS_LOADING_CONFIG
+IS_LOADING_CONFIG = False
 
 
 def get_is_no_color():
@@ -16,6 +21,26 @@ def colorize(val, color, add_reset=True):
     return color + val + ("\033[0m" if add_reset else "")
 
 
+def get_calling_frame_objects_by_type(otype: Type, offset: int = 1, first_only=False):
+    frames = inspect.stack()
+    frames = frames[offset:]
+    lst = []
+    for f in frames:
+        if "self" not in f.frame.f_locals:
+            continue
+        obj = f.frame.f_locals["self"]
+        if not isinstance(obj, otype):
+            continue
+        if first_only:
+            return obj
+        lst.append(obj)
+
+    if first_only:
+        return None
+
+    return lst
+
+
 class style:
     GRAY = lambda x: colorize(str(x), "\033[90m")  # noqa: E731
     LIGHT_GRAY = lambda x: colorize(str(x), "\033[37m")  # noqa: E731
